@@ -1,27 +1,11 @@
 import inspect
 from abc import ABCMeta, abstractmethod
 from functools import update_wrapper
-from fixate.core.discover import open_instrument
 from fixate.core.exceptions import InstrumentFeatureUnavailable
 
-try:
-    import typing
+import typing
 
-    number = typing.Union[float, int]
-except ImportError:
-    number = float
-
-
-def open():
-    """Open is the public api for the dmm driver for discovering and opening a connection
-    to a valid Digital Multimeter.
-    At the moment opens the first dmm connected
-    :param restrictions:
-    A dictionary containing the technical specifications of the required equipment
-    :return:
-    A instantiated class connected to a valid dmm
-    """
-    return open_instrument("DSO")
+number = typing.Union[float, int]
 
 
 class CallableNoArgs:
@@ -699,6 +683,7 @@ class Measure:
         self.delay = Delay()
         self.duty = MeasureAllSources()
         self.fall_time = MeasureAllSources()
+        self.rise_time = MeasureAllSources()
         self.frequency = MeasureAllSources()
         self.cnt_edge_rising = MeasureAllSources()
         self.cnt_edge_falling = MeasureAllSources()
@@ -710,6 +695,7 @@ class Measure:
         self.vamplitude = MeasureAllSources()
         self.vaverage = MeasureInterval()
         self.vbase = MeasureAllSources()
+        self.vtop = MeasureAllSources()
         self.vmax = MeasureAllSources()
         self.vmin = MeasureAllSources()
         self.vpp = MeasureAllSources()
